kinto-wizard
============

|pypi| |ci|

.. |pypi| image:: https://img.shields.io/pypi/v/kinto-wizard.svg
    :target: https://pypi.python.org/pypi/kinto-wizard
.. |ci| image::  https://img.shields.io/github/actions/workflow/status/Kinto/kinto-wizard/test.yml?branch=main
    :target: https://github.com/Kinto/kinto-wizard/actions

kinto-wizard is a tool that lets you setup an entire Kinto server from
a Yaml file, or inspect an existing server and output a Yaml file.

You can define Kinto objects (bucket, collection, groups, records)
and configure their attributes and permissions.

Installation
------------

Use pip:

.. code-block:: bash

    $ pip install kinto-wizard


How to use it?
--------------

Load
~~~~

.. code-block:: bash

    kinto-wizard load \
        --server https://kinto-writer.stage.mozaws.net/v1 \
        --auth admin:credentials \
        new-config.yml

The load command also accepts these options:

* ``--data`` - Load data attributes.
* ``--permissions``: - Load objects permissions.
* ``--collections`` - Load collections.
* ``--groups`` - Load groups.
* ``--records`` - Load collections` records.
* ``--attachments`` - Load the attachments files from the specified folder
* ``--full`` - Combination of all flags (default).

Dump
~~~~

.. code-block:: bash

    kinto-wizard dump \
        --server https://kinto-writer.stage.mozaws.net/v1 \
        --auth admin:credentials \
        > current-config.yml

The dump command also accepts these options:

* ``--data`` - Include buckets, collections and groups data (attachments, schemas, display fields, uischema etc.).
* ``--permissions``: - Include objects permissions.
* ``--collections`` - Include collections.
* ``--groups`` - Include groups.
* ``--records`` - Include collections` records.
* ``--attachments`` - Save the attachments files into the specified folder
* ``--full`` - Combination of all flags (default).

Validate a dump
---------------

The way Kinto works is by letting you change a collection schema but
won't enforce the new schema for existing records.

When you dump a collection and its records, you can end-up having
records that Kinto won't let you upload back because the schema
changed and they are invalid with the current schema.

This can lead to unexpected behavior on loading time which is a bit
cumbersome because depending of the size of the file you are loading,
it can takes a long time before getting an actual error.

In order to fix the file before loading, you can use the validate
command that would give you the error Kinto would return if you were
to load the file on a Kinto server.


.. code-block:: bash

    kinto-wizard validate current-config.yml


Development
-----------

See `contributing docs <./.github/CONTRIBUTING.md>`_
